@@ -18,7 +18,7 @@ from jdatetime.jalali import (
     GregorianToJalali, JalaliToGregorian, j_days_in_month,
 )
 
-__VERSION__ = "4.1.0"
+__VERSION__ = "4.1.1"
 MINYEAR = 1
 MAXYEAR = 9377
 
@@ -333,6 +333,21 @@ class date:
         (y, m, d) = GregorianToJalali(d.year, d.month, d.day).getJalaliList()
         return date(y, m, d)
 
+    @staticmethod
+    def fromisoformat(date_string: str):
+        """
+        Convert an ISO 8601 formatted string to a jdatetime.date
+        """
+        if not isinstance(date_string, str):
+            raise TypeError("fromisoformat: argument must be str")
+
+        iso_format_regex = r"(\d{4})-?(\d{2})-?(\d{2})"
+        matched_str = re.fullmatch(iso_format_regex, date_string)
+        if matched_str is not None:
+            return date(*map(int, matched_str.groups()))
+        else:
+            raise ValueError(f'Invalid isoformat string: {date_string!r}')
+
     def toordinal(self):
         """Return proleptic jalali ordinal. Farvardin 1 of year 1 which is equal to 622-3-21 of Gregorian."""
         d = self.togregorian()
@@ -648,17 +663,17 @@ date.min = date(MINYEAR, 1, 1)
 date.max = date(MAXYEAR, 12, 30)
 
 _DIRECTIVE_PATTERNS = {
-    '%Y': '(?P<Y>\d{4})',
-    '%y': '(?P<y>\d{2})',
-    '%m': '(?P<m>\d{1,2})',
-    '%d': '(?P<d>\d{1,2})',
-    '%H': '(?P<H>\d{1,2})',
-    '%M': '(?P<M>\d{1,2})',
-    '%S': '(?P<S>\d{1,2})',
-    '%f': '(?P<f>\d{1,6})',
-    '%B': '(?P<B>[a-zA-Z\u0600-\u06EF\uFB8A\u067E\u0686\u06AF]{3,12})',
-    '%b': '(?P<b>[a-zA-Z]{3})',
-    '%z': '(?P<z>[+-]\d\d:?[0-5\u06F0-\u06F5]\d(:?[0-5\u06F0-\u06F5]\d(\.\d{1,6})?)?)',
+    '%Y': r'(?P<Y>\d{4})',
+    '%y': r'(?P<y>\d{2})',
+    '%m': r'(?P<m>\d{1,2})',
+    '%d': r'(?P<d>\d{1,2})',
+    '%H': r'(?P<H>\d{1,2})',
+    '%M': r'(?P<M>\d{1,2})',
+    '%S': r'(?P<S>\d{1,2})',
+    '%f': r'(?P<f>\d{1,6})',
+    '%B': r'(?P<B>[a-zA-Z\u0600-\u06EF\uFB8A\u067E\u0686\u06AF]{2,12})',
+    '%b': r'(?P<b>[a-zA-Z]{3})',
+    '%z': r'(?P<z>[+-]\d\d:?[0-5\u06F0-\u06F5]\d(:?[0-5\u06F0-\u06F5]\d(\.\d{1,6})?)?)',
 }
 
 # Replace directives with patterns according to _DIRECTIVE_PATTERNS
@@ -797,6 +812,21 @@ class datetime(date):
             now_datetime.microsecond,
         )
 
+    @classmethod
+    def fromisoformat(cls, date_string: str):
+        """
+        Convert an ISO 8601 formatted string to a jdatetime.datetime
+        """
+        # Since we do not (yet?) support ISO week dates, the date and time
+        # separator is either at 8th or 10th position, see:
+        # https://github.com/python/cpython/blob/b2b85b5db9cfdb24f966b61757536a898abc3830/Lib/datetime.py#L271
+        separator_position = 10 if date_string[4] == '-' else 8
+        time_string = date_string[separator_position + 1:]
+        return cls.combine(
+            date.fromisoformat(date_string[:separator_position]),
+            time.fromisoformat(time_string) if time_string else time(),
+        )
+
     @staticmethod
     def fromtimestamp(timestamp, tz=None):
         """timestamp[, tz] -> tz's local time from POSIX timestamp."""
